NLSL: eprmat Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
eprmat Module Reference

## Variables
double precision, dimension(mxel), save | zmat
double precision, dimension(2, mxdim), save | zdiag
integer, dimension(mxel), save | izmat
integer, dimension(mxdim+1), save | jzmat
integer, dimension(mxdim+1), save | kzmat

## Variable Documentation

integer, dimension(mxel), save eprmat::izmat

Definition at line 50 of file eprmat.f90.

integer, dimension(mxdim+1), save eprmat::jzmat

Definition at line 50 of file eprmat.f90.

integer, dimension(mxdim+1), save eprmat::kzmat

Definition at line 50 of file eprmat.f90.

double precision, dimension(2,mxdim), save eprmat::zdiag

Definition at line 49 of file eprmat.f90.

double precision, dimension(mxel), save eprmat::zmat

Definition at line 49 of file eprmat.f90.